@@ -8,7 +8,7 @@
 #' @family model_helpers
 #' @seealso [stats::model.matrix()]
 #' @examples
-#' lm(hp ~ mpg + factor(cyl), mtcars) %>%
+#' lm(hp ~ mpg + factor(cyl), mtcars) |>
 #'   model_get_assign()
 model_get_assign <- function(model) {
   UseMethod("model_get_assign")
@@ -19,7 +19,7 @@ model_get_assign <- function(model) {
 model_get_assign.default <- function(model) {
   model_matrix <- model_get_model_matrix(model)
   get_assign <- purrr::attr_getter("assign")
-  assign <- model_matrix %>% get_assign()
+  assign <- model_matrix |> get_assign()
 
   if (is.null(assign)) {
     # an alternative generic way to compute assign
@@ -30,7 +30,7 @@ model_get_assign.default <- function(model) {
         NULL # nocov
       }
     )
-    assign <- model_matrix %>% get_assign()
+    assign <- model_matrix |> get_assign()
   }
 
   if (!is.atomic(assign)) {
@@ -46,7 +46,7 @@ model_get_assign.default <- function(model) {
 model_get_assign.vglm <- function(model) {
   model_matrix <- model_get_model_matrix(model)
   get_assign <- purrr::attr_getter("orig.assign.lm")
-  assign <- model_matrix %>% get_assign()
+  assign <- model_matrix |> get_assign()
   attr(assign, "model_matrix") <- model_matrix
   assign
 }
