@@ -6,7 +6,7 @@
 #' * `variable`: variable name
 #' * `contrasts`: contrasts used
 #' * `contrasts_type`: type of contrasts
-#'   ("treatment", "sum", "poly", "helmert", "other" or "no.contrast")
+#'   ("treatment", "sum", "poly", "helmert", "sdiff, "other" or "no.contrast")
 #' * `reference`: for variables with treatment, SAS
 #'   or sum contrasts, position of the reference level
 #' @details
@@ -21,7 +21,7 @@
 #'   data = mtcars,
 #'   family = binomial,
 #'   contrasts = list(`factor(cyl)` = contr.sum)
-#' ) %>%
+#' ) |>
 #'   model_list_contrasts()
 model_list_contrasts <- function(model) {
   UseMethod("model_list_contrasts")
@@ -46,21 +46,26 @@ model_list_contrasts.default <- function(model) {
 
   for (i in seq_len(nrow(contrasts_list))) {
     n_levels <- length(xlevels[[contrasts_list$variable[i]]])
-    n_terms <- model_variables %>%
-      dplyr::filter(.data$variable == contrasts_list$variable[i]) %>%
+    n_terms <- model_variables |>
+      dplyr::filter(.data$variable == contrasts_list$variable[i]) |>
       nrow()
 
     if (n_levels == n_terms) {
       contrasts_list$contrasts[[i]] <- "no.contrast"
     } else if (
       is.character(model_contrasts[[i]]) &&
-      length(is.character(model_contrasts[[i]]) == 1)
+        length(is.character(model_contrasts[[i]]) == 1)
     ) {
       contrasts_list$contrasts[[i]] <- model_contrasts[[i]]
-      if (model_contrasts[[i]] == "contr.treatment")
+      if (model_contrasts[[i]] == "contr.treatment") {
         contrasts_list$reference[[i]] <- 1
-      if (model_contrasts[[i]] == "contr.SAS" || model_contrasts[[i]] == "contr.sum")
+      }
+      if (model_contrasts[[i]] == "contr.SAS" || model_contrasts[[i]] == "contr.sum") {
         contrasts_list$reference[[i]] <- n_levels
+      }
+      if (model_contrasts[[i]] == "contr.sdif") {
+        contrasts_list$reference[[i]] <- NA
+      }
     } else if (all(model_contrasts[[i]] == stats::contr.treatment(n_levels))) {
       contrasts_list$contrasts[[i]] <- "contr.treatment"
       contrasts_list$reference[[i]] <- 1
@@ -74,6 +79,12 @@ model_list_contrasts.default <- function(model) {
     } else if (all(model_contrasts[[i]] == stats::contr.SAS(n_levels))) {
       contrasts_list$contrasts[[i]] <- "contr.SAS"
       contrasts_list$reference[[i]] <- n_levels
+    } else if (
+      .assert_package("MASS", boolean = TRUE) &&
+        all(model_contrasts[[i]] == MASS::contr.sdif(n_levels))
+    ) {
+      contrasts_list$contrasts[[i]] <- "contr.sdif"
+      contrasts_list$reference[[i]] <- NA
     } else {
       for (j in 2:n_levels) { # testing treatment coding width different value for base variable
         if (all(model_contrasts[[i]] == stats::contr.treatment(n_levels, base = j))) {
@@ -88,14 +99,15 @@ model_list_contrasts.default <- function(model) {
       contrasts_list$contrasts[[i]] <- "custom"
     }
   }
-  contrasts_list %>%
+  contrasts_list |>
     dplyr::mutate(
       contrasts_type = dplyr::case_when(
-        .data$contrasts %>% stringr::str_starts("contr.treatment") ~ "treatment",
+        .data$contrasts |> stringr::str_starts("contr.treatment") ~ "treatment",
         .data$contrasts == "contr.SAS" ~ "treatment",
         .data$contrasts == "contr.sum" ~ "sum",
         .data$contrasts == "contr.helmert" ~ "helmert",
         .data$contrasts == "contr.poly" ~ "poly",
+        .data$contrasts == "contr.sdif" ~ "sdif",
         .data$contrasts == "no.contrast" ~ "no.contrast",
         TRUE ~ "other"
       )
