@@ -1,7 +1,3 @@
-#' @importFrom dplyr `%>%`
-#' @export
-dplyr::`%>%`
-
 #' @importFrom dplyr vars
 #' @export
 dplyr::vars
