@@ -1,7 +1,7 @@
 #' Add an estimate value to references rows for categorical variables
 #'
 #' For categorical variables with a treatment contrast
-#' ([stats::contr.treatment()]) or a SAS contrast ([stats::contr.SAS()])
+#' ([stats::contr.treatment()]) or a SAS contrast ([stats::contr.SAS()]),
 #' will add an estimate equal to `0` (or `1` if `exponentiate = TRUE`)
 #' to the reference row.
 #'
@@ -33,45 +33,45 @@
 #' @family tidy_helpers
 #' @examplesIf interactive()
 #' if (.assert_package("gtsummary", boolean = TRUE) && .assert_package("emmeans", boolean = TRUE)) {
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   dplyr::mutate(dplyr::across(where(is.character), factor))
+#'   df <- Titanic |>
+#'     dplyr::as_tibble() |>
+#'     dplyr::mutate(dplyr::across(where(is.character), factor))
 #'
-#' df %>%
 #'   glm(
 #'     Survived ~ Class + Age + Sex,
-#'     data = ., weights = .$n, family = binomial,
+#'     data = df, weights = df$n, family = binomial,
 #'     contrasts = list(Age = contr.sum, Class = "contr.SAS")
-#'   ) %>%
-#'   tidy_and_attach(exponentiate = TRUE) %>%
-#'   tidy_add_reference_rows() %>%
-#'   tidy_add_estimate_to_reference_rows()
+#'   ) |>
+#'     tidy_and_attach(exponentiate = TRUE) |>
+#'     tidy_add_reference_rows() |>
+#'     tidy_add_estimate_to_reference_rows()
 #'
-#' glm(
-#'   response ~ stage + grade * trt,
-#'   gtsummary::trial,
-#'   family = binomial,
-#'   contrasts = list(
-#'     stage = contr.treatment(4, base = 3),
-#'     grade = contr.treatment(3, base = 2),
-#'     trt = contr.treatment(2, base = 2)
-#'   )
-#' ) %>%
-#'   tidy_and_attach() %>%
-#'   tidy_add_reference_rows() %>%
-#'   tidy_add_estimate_to_reference_rows()
+#'   glm(
+#'     response ~ stage + grade * trt,
+#'     gtsummary::trial,
+#'     family = binomial,
+#'     contrasts = list(
+#'       stage = contr.treatment(4, base = 3),
+#'       grade = contr.treatment(3, base = 2),
+#'       trt = contr.treatment(2, base = 2)
+#'     )
+#'   ) |>
+#'     tidy_and_attach() |>
+#'     tidy_add_reference_rows() |>
+#'     tidy_add_estimate_to_reference_rows()
 #' }
 tidy_add_estimate_to_reference_rows <- function(
-  x,
-  exponentiate = attr(x, "exponentiate"),
-  conf.level = attr(x, "conf.level"),
-  model = tidy_get_model(x),
-  quiet = FALSE
-) {
-  if (is.null(exponentiate) || !is.logical(exponentiate))
+    x,
+    exponentiate = attr(x, "exponentiate"),
+    conf.level = attr(x, "conf.level"),
+    model = tidy_get_model(x),
+    quiet = FALSE) {
+  if (is.null(exponentiate) || !is.logical(exponentiate)) {
     cli::cli_abort("{.arg exponentiate} is not provided. You need to pass it explicitely.")
-  if (is.null(conf.level) || !is.numeric(conf.level))
+  }
+  if (is.null(conf.level) || !is.numeric(conf.level)) {
     cli::cli_abort("{.arg conf.level} is not provided. You need to pass it explicitely.")
+  }
 
   if (is.null(model)) {
     cli::cli_abort(c(
@@ -84,15 +84,15 @@ tidy_add_estimate_to_reference_rows <- function(
   .attributes$exponentiate <- exponentiate
 
   if (!"reference_row" %in% names(x)) {
-    x <- x %>% tidy_add_reference_rows(model = model)
+    x <- x |> tidy_add_reference_rows(model = model)
   }
 
   if (!"estimate" %in% names(x)) { # to avoid a problem with certain types of model (e.g. gam)
-    return(x %>% tidy_attach_model(model))
+    return(x |> tidy_attach_model(model))
   }
 
   # treatment contrasts
-  x <- x %>%
+  x <- x |>
     dplyr::mutate(
       estimate = dplyr::if_else(
         !is.na(.data$reference_row) &
@@ -124,28 +124,29 @@ tidy_add_estimate_to_reference_rows <- function(
     }
   }
 
-  x %>%
+  x |>
     tidy_attach_model(model = model, .attributes = .attributes)
 }
 
 
 .get_ref_row_estimate_contr_sum <- function(variable, model, exponentiate = FALSE,
                                             conf.level = .95, quiet = FALSE) {
-
   if (inherits(model, "multinom")) {
     dc <- NULL
-    if (!quiet)
+    if (!quiet) {
       cli_alert_info(paste0(
         "Sum contrasts are not supported for 'multinom' models.\n",
         "Reference row of variable '", variable, "' remained unchanged."
       ))
+    }
   } else if (inherits(model, "LORgee")) {
     dc <- NULL
-    if (!quiet)
+    if (!quiet) {
       cli_alert_info(paste0(
         "Sum contrasts are not supported for {.pkg multgee} models.\n",
         "Reference row of variable '", variable, "' remained unchanged."
       ))
+    }
   } else {
     .assert_package("emmeans", fn = "broom.helpers::tidy_add_estimate_to_reference_rows()")
 
@@ -154,11 +155,12 @@ tidy_add_estimate_to_reference_rows <- function(
         emmeans::emmeans(model, specs = variable, contr = "eff")
       ),
       error = function(e) {
-        if (!quiet)
+        if (!quiet) {
           cli_alert_info(paste0(
             "No emmeans() method for this type of model.\n",
             "Reference row of variable '", variable, "' remained unchanged."
           ))
+        }
         NULL
       }
     )
@@ -173,13 +175,13 @@ tidy_add_estimate_to_reference_rows <- function(
       conf.high = NA_real_
     )
   } else {
-    res <- dc$contrasts %>%
-      as.data.frame(destroy.annotations = TRUE) %>%
-      dplyr::last() %>%
+    res <- dc$contrasts |>
+      as.data.frame(destroy.annotations = TRUE) |>
+      dplyr::last() |>
       dplyr::select("estimate", std.error = "SE", "p.value")
-    ci <- dc$contrasts %>%
-      stats::confint(level = conf.level) %>%
-      as.data.frame() %>%
+    ci <- dc$contrasts |>
+      stats::confint(level = conf.level) |>
+      as.data.frame() |>
       dplyr::last()
     if ("asymp.LCL" %in% names(ci)) {
       res$conf.low <- ci$asymp.LCL
@@ -194,7 +196,6 @@ tidy_add_estimate_to_reference_rows <- function(
       res$conf.low <- NA_real_
       res$conf.high <- NA_real_
     }
-
   }
 
   if (exponentiate) {
