@@ -21,17 +21,16 @@
 #' @export
 #' @family tidy_helpers
 #' @examples
-#' df <- Titanic %>%
-#'   dplyr::as_tibble() %>%
-#'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes"))) %>%
+#' df <- Titanic |>
+#'   dplyr::as_tibble() |>
+#'   dplyr::mutate(Survived = factor(Survived, c("No", "Yes"))) |>
 #'   labelled::set_variable_labels(
 #'     Class = "Passenger's class",
 #'     Sex = "Sex"
 #'   )
 #'
-#' df %>%
-#'   glm(Survived ~ Class * Age * Sex, data = ., weights = .$n, family = binomial) %>%
-#'   tidy_and_attach() %>%
+#' glm(Survived ~ Class * Age * Sex, data = df, weights = df$n, family = binomial) |>
+#'   tidy_and_attach() |>
 #'   tidy_add_variable_labels(
 #'     labels = list(
 #'       "(Intercept)" = "Custom intercept",
@@ -46,21 +45,27 @@ tidy_add_variable_labels <- function(x,
                                      quiet = FALSE,
                                      strict = FALSE) {
   if (is.null(model)) {
-    stop("'model' is not provided. You need to pass it or to use 'tidy_and_attach()'.")
+    cli::cli_abort(c(
+      "{.arg model} is not provided.",
+      "You need to pass it or to use {.fn tidy_and_attach}."
+    ))
   }
 
   if ("header_row" %in% names(x)) {
-    stop("`tidy_add_variable_labels()` cannot be applied after `tidy_add_header_rows().`")
+    cli::cli_abort(paste(
+      "{.fn tidy_add_variable_labels} cannot be applied",
+      "after {.fn tidy_add_header_rows}."
+    ))
   }
 
   .attributes <- .save_attributes(x)
 
   if ("var_label" %in% names(x)) {
-    x <- x %>% dplyr::select(-dplyr::all_of("var_label"))
+    x <- x |> dplyr::select(-dplyr::all_of("var_label"))
   }
 
-  if (!"variable" %in% names(x)) {
-    x <- x %>% tidy_identify_variables(model = model)
+  if (!"variable" %in% names(x) || !"var_type" %in% names(x)) {
+    x <- x |> tidy_identify_variables(model = model)
   }
 
   labels <- .formula_list_to_named_list(labels, var_info = x, arg_name = "labels")
@@ -73,16 +78,16 @@ tidy_add_variable_labels <- function(x,
   names(var_labels) <- var_labels
 
   # add the list of variables from x
-  additional_labels <- x$variable[!is.na(x$variable)] %>% unique()
+  additional_labels <- x$variable[!is.na(x$variable)] |> unique()
   names(additional_labels) <- additional_labels
-  var_labels <- var_labels %>%
+  var_labels <- var_labels |>
     .update_vector(additional_labels)
 
   # add the list of variables from model_list_variables
   variable_list <- model_list_variables(model, labels = labels)
   additional_labels <- variable_list$var_label
   names(additional_labels) <- variable_list$variable
-  var_labels <- var_labels %>%
+  var_labels <- var_labels |>
     .update_vector(additional_labels)
 
   # check if all elements of labels are in x
@@ -92,10 +97,10 @@ tidy_add_variable_labels <- function(x,
     cli_alert_danger("{.code {not_found}} terms have not been found in {.code x}.")
   }
   if (length(not_found) > 0 && strict) {
-    stop("Incorrect call with `labels=`. Quitting execution.", call. = FALSE)
+    cli::cli_abort("Incorrect call with `labels=`. Quitting execution.", call = NULL)
   }
 
-  var_labels <- var_labels %>%
+  var_labels <- var_labels |>
     .update_vector(labels)
 
   # save custom labels
@@ -107,21 +112,21 @@ tidy_add_variable_labels <- function(x,
   interaction_terms <- setdiff(interaction_terms, names(labels))
   names(interaction_terms) <- interaction_terms
   # compute labels for interaction terms
-  interaction_terms <- interaction_terms %>%
-    strsplit(":") %>%
+  interaction_terms <- interaction_terms |>
+    strsplit(":") |>
     lapply(function(x) {
       paste(var_labels[x], collapse = interaction_sep)
-    }) %>%
+    }) |>
     unlist()
-  var_labels <- var_labels %>% .update_vector(interaction_terms)
+  var_labels <- var_labels |> .update_vector(interaction_terms)
 
-  x %>%
+  x |>
     dplyr::left_join(
       tibble::tibble(
         variable = names(var_labels),
         var_label = var_labels
       ),
       by = "variable"
-    ) %>%
+    ) |>
     tidy_attach_model(model = model, .attributes = .attributes)
 }
